==> owncloud-9.0.3.tgz: owncloud/core/l10n/sr@latin.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nije bilo moguće poslati e-mail sledećim korisnicima: %s",
    "Turned on maintenance mode" : "Uključen je režim za održavanje",
    "Turned off maintenance mode" : "Isključen je režim za održavanje",
    "Updated database" : "Osvežena je baza podataka",
    "Checked database schema update" : "Provereno je osvežavanje šema baze podataka",
    "Checked database schema update for apps" : "Provereno je osvežavanje šema baze podataka za aplikacije",
    "Updated \"%s\" to %s" : "Osveženo je \"%s\" na \"%s\"",
    "No image or file provided" : "Nije data slika ili fajl",
    "Unknown filetype" : "Nepoznat tip fajla",
    "Invalid image" : "Neispravna slika",
    "No temporary profile picture available, try again" : "Nije dostupna privremena slika profila, pokušajte ponovo",
    "No crop data provided" : "Nisu dati podaci za sečenje slike",
    "Couldn't reset password because the token is invalid" : "Nije bilo moguće ponovo postaviti lozinku zbog nevažećeg kontrolnog broja",
    "Couldn't send reset email. Please make sure your username is correct." : "Nije bilo moguće poslati Email za ponovno postavljanje. Molimo Vas da proverite da li je Vaše korisničko ime ispravno.",
    "%s password reset" : "%s lozinka ponovo postavljena",
    "Couldn't send reset email. Please contact your administrator." : "Nemoguće slanje e-mail-a za ponovno postavljanje lozinke. Molimo Vas kontaktirajte Vašeg administratora",
    "Sunday" : "Nedelja",
    "Monday" : "Ponedeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Sreda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "ned",
    "Mon." : "pon",
    "Tue." : "uto",
    "Wed." : "sre",
    "Thu." : "čet",
    "Fri." : "pet",
    "Sat." : "sub",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mart",
    "April" : "April",
    "May" : "Maj",
    "June" : "Jun",
    "July" : "Jul",
    "August" : "Avgust",
    "September" : "Septembar",
    "October" : "Oktobar",
    "November" : "Novembar",
    "December" : "Decembar",
    "Jan." : "jan",
    "Feb." : "feb",
    "Mar." : "mar",
    "Apr." : "apr",
    "May." : "maj",
    "Jun." : "jun",
    "Jul." : "jul",
    "Aug." : "avg",
    "Sep." : "sep",
    "Oct." : "okt",
    "Nov." : "nov",
    "Dec." : "dec",
    "Settings" : "Podešavanja",
    "Saving..." : "Snimam...",
    "seconds ago" : "Pre par sekundi",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link za ponovno postavljanje Vaše lozinke je poslat na Vašu e-mail adresu. Ako ga ne primite u razumnom roku, proverite fascikle za neželjenu poštu.<br>Ako ga nema ni tamo, kontaktirajte Vašeg lokalnog administratora.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaši fajlovi su šifrovani. Ako nista omogućili ključ za povrat fajlova, neće biti načina da dobijete ponovo svoje podatke posle promene lozinke.<br />Ako niste sigurni šta da radite, molimo Vas da kontaktirate Vašeg administratora pre nego što nastavite.<br />Da li zaista želite da nastavite?",
    "I know what I'm doing" : "Znam šta radim",
    "Password can not be changed. Please contact your administrator." : "Nije moguće promeniti lozinku. Molimo Vas, kontaktirajte Vašeg administratora.",
    "No" : "Ne",
    "Yes" : "Da",
    "Choose" : "Izaberi",
    "Error loading file picker template: {error}" : "Greška u učitavanju obrasca za izbor fajla: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Greška u učitavanju obrasca poruke: {error}",
    "read-only" : "samo za čitanje",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt fajlova","{count} konflikata fajlova","{count} konflikata fajlova"],
    "One file conflict" : "Jedan konflikt fajlova",
    "New Files" : "Novi Fajlovi",
    "Already existing files" : "Već postojeći fajlovi",
    "Which files do you want to keep?" : "Koje fajlove želite da zadržite ?",
    "If you select both versions, the copied file will have a number added to its name." : "Ako izaberete obe verzije, kopirani fajl će imati broj dodat njegovom imenu.",
    "Cancel" : "Otkaži",
    "Continue" : "Nastavi",
    "(all selected)" : "(svi izabrani)",
    "({count} selected)" : "(izabrano {count})",
    "Error loading file exists template" : "Greška u učitavanju obrasca za postojeći fajl",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Osrednja lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Error occurred while checking server setup" : "Došlo je do greške prilikom provere startovanja servera",
    "Shared" : "Deljeno",
    "Shared with {recipients}" : "Podeljeno sa {recipients}",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri deljenju",
    "Error while unsharing" : "Greška u uklanjanju deljenja",
    "Error setting expiration date" : "Greška u postavljanju datuma isteka",
    "The public link will expire no later than {days} days after it is created" : "Javna prečica će isteći ne kasnije od {days} dana pošto je kreirana",
    "Set expiration date" : "Datum isteka",
    "Expiration" : "Isticanje",
    "Expiration date" : "Datum isteka",
    "Choose a password for the public link" : "Izaberite lozinku za javnu prečicu",
    "Sending ..." : "Slanje...",
    "Email sent" : "Email poslat",
    "Resharing is not allowed" : "Dalje deljenje nije dozvoljeno",
    "Share link" : "Podeli prečicu",
    "Link" : "Prečica",
    "Password protect" : "Zaštita lozinkom",
    "Password" : "Lozinka",
    "Allow editing" : "Dozvoli uređivanje",
    "Email link to person" : "Pošalji link e-mailom",
    "Send" : "Pošalji",
    "Shared with you and the group {group} by {owner}" : "{owner} podelio sa Vama i grupom {group} ",
    "Shared with you by {owner}" : "Sa vama podelio {owner}",
    "group" : "grupa",
    "remote" : "udaljeni",
    "notify by email" : "obavesti Email-om",
    "Unshare" : "Ukljoni deljenje",
    "can share" : "dozvoljeno deljenje",
    "can edit" : "dozvoljene izmene",
    "create" : "napravi",
    "change" : "izmeni",
    "delete" : "brisanje",
    "access control" : "kontrola pristupa",
    "Share" : "Podeli",
    "Warning" : "Upozorenje",
    "Delete" : "Obriši",
    "Rename" : "Preimenuj",
    "The object type is not specified." : "Tip objekta nije zadan.",
    "Enter new" : "Unesite novi",
    "Add" : "Dodaj",
    "Edit tags" : "Uredi oznake",
    "Error loading dialog template: {error}" : "Greška pri učitavanju obrasca dijaloga: {error}",
    "No tags selected for deletion." : "Nijedna oznaka nije izabrana za brisanje.",
    "unknown text" : "nepoznati tekst",
    "Hello world!" : "Zdravo Svete!",
    "sunny" : "sunčano",
    "Hello {name}, the weather is {weather}" : "Zdravo {name}, vreme je {weather}",
    "_download %n file_::_download %n files_" : ["Preuzmi %n fajl","Preuzmi %n fajlova","Preuzmi %n fajlova"],
    "Updating {productName} to version {version}, this may take a while." : "Osvežavam {productName} na verziju {version}, ovo može potrajati.",
    "Please reload the page." : "Molimo, ponovo učitajte stranu.",
    "The update was unsuccessful. " : "Osvežavanje je uspelo.",
    "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspelo. Prosleđivanje na ownCloud.",
    "Personal" : "Lično",
    "Users" : "Korisnici",
    "Apps" : "Programi",
    "Admin" : "Adninistracija",
    "Help" : "Pomoć",
    "Error loading tags" : "Greška pri učitavanju oznaka",
    "Tag already exists" : "Oznaka već postoji",
    "Error deleting tag(s)" : "Greška pri brisanju oznaka",
    "Error tagging" : "Greška pri postavljanju oznake",
    "Error untagging" : "Greška pri uklanjanju oznake",
    "Error favoriting" : "Greška pri dodavanju omiljenog",
    "Error unfavoriting" : "Greška pri uklanjanju omiljenog",
    "Access forbidden" : "Pristup zabranjen",
    "File not found" : "Fajl nije nađen",
    "The specified document has not been found on the server." : "Traženi dokument nije nađen na serveru.",
    "You can click here to return to %s." : "Možete ovde kliknuti da biste se vratili na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej,\n\nsamo da ti javimo da je %s delio %s sa tobom.\nPogledaj na: %s\n\n",
    "The share will expire on %s." : "Deljeni sadržaj će isteći: %s",
    "Cheers!" : "U zdravlje!",
    "Internal Server Error" : "Interna Serverska Greška",
    "The server encountered an internal error and was unable to complete your request." : "Server je naišao na internu grešku i nije mogao da završi obradu Vašeg upita.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Molimo Vas da kontaktirate administratora servera ako se ova greška ponavlja, molimo da uključite tehničke podatke dole u Vašem izveštaju.",
    "More details can be found in the server log." : "Više detalja se može naći u serverovom logu - zapisniku.",
    "Technical details" : "Tehnički detalji",
    "Remote Address: %s" : "Udaljena adresa: %s",
    "Request ID: %s" : "ID zahteva: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Poruka: %s",
    "File: %s" : "Fajl: %s",
    "Line: %s" : "Linija: %s",
    "Trace" : "Zapisnik: ",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vaši podaci i direktorijumi su verovatno dostupni sa interneta jer .htaccess fajl ne funkcioniše.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Za informacije kako da pravilno podesite server, molimo Vas da pogledate <a href=\"%s\" target=\"_blank\">dokumentaciju</a>.",
    "Create an <strong>admin account</strong>" : "Napravi <strong>administrativni nalog</strong>",
    "Username" : "Korisničko ime",
    "Storage & database" : "Skladište i baza podataka",
    "Data folder" : "Fascikla podataka",
    "Configure the database" : "Podešavanje baze",
    "Only %s is available." : "Samo %s je na raspolaganju.",
    "Database user" : "Korisnik baze",
    "Database password" : "Lozinka baze",
    "Database name" : "Ime baze",
    "Database tablespace" : "tablespace baze",
    "Database host" : "Domaćin baze",
    "Finish setup" : "Završi podešavanje",
    "Finishing …" : "Završavam ...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej,<br><br>samo ti javljamo da je %s delio <strong>%s</strong> sa tobom.<br><a href=\"%s\">Pogledaj!</a><br><br>",
    "Log out" : "Odjava",
    "Search" : "Traži",
    "Server side authentication failed!" : "Provera identiteta na stani servera nije uspela!",
    "Please contact your administrator." : "Molimo Vas da kontaktirate Vašeg administratora.",
    "Log in" : "Prijavi se",
    "Alternative Logins" : "Alternativne prijave",
    "Use the following link to reset your password: {link}" : "Koristite sledeći link za reset lozinke: {link}",
    "New password" : "Nova lozinka",
    "New Password" : "Nova lozinka",
    "Reset password" : "Resetuj lozinku",
    "This ownCloud instance is currently in single user mode." : "Ova instanca ownCloud-a je trenutno u režimu rada jednog korisnika.",
    "This means only administrators can use the instance." : "Ovo znači da samo administratori mogu da koriste ovu instancu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktirajte Vašeg sistem administratora ako se ova poruka često ili iznenada pojavljuje.",
    "Thank you for your patience." : "Hvala Vam na strpljenju.",
    "You are accessing the server from an untrusted domain." : "Pristupate serveru sa nepouzdanog domena.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "U zavisnosti od Vaše konfiguracije, kao administrator bi ste mogli da upotrebite dugme ispod da podesite da verujete ovom domenu.",
    "Add \"%s\" as trusted domain" : "Dodaj \"%s\" kao domen od poverenja",
    "The theme %s has been disabled." : "Tema %s će biti onemogućena.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Molimo Vas da proverite da li su baza podataka, fascikla sa podešavanjima i fascikla sa podacima bekapovani pre nego što nastavite.",
    "Start update" : "Započni osvežavanje",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Da bi izbegli preduga čekanja na većim instalacijama, možete pokrenuti sledeću komandu iz instalacionog direktorijuma:",
    "This page will refresh itself when the %s instance is available again." : "Ova stranica će se sama osvežiti kada %s instanca ponovo postane dostupna.",
    "Error loading file picker template: {error}" : "Greška u učitavanju obrasca za izbor fajla: {error}",
    "You can click here to return to %s." : "Možete ovde kliknuti da biste se vratili na %s.",
    "Password can not be changed. Please contact your administrator." : "Nije moguće promeniti lozinku. Molimo Vas, kontaktirajte Vašeg administratora.",
    "Shared with you by {owner}" : "Sa vama podelio {owner}"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.0.7.tgz: owncloud/core/l10n/sr@latin.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "Nije data slika ili fajl",
    "Unknown filetype" : "Nepoznat tip fajla",
    "Invalid image" : "Neispravna slika",
    "No temporary profile picture available, try again" : "Nije dostupna privremena slika profila, pokušajte ponovo",
    "No crop data provided" : "Nisu dati podaci za sečenje slike",
    "Couldn't reset password because the token is invalid" : "Nije bilo moguće ponovo postaviti lozinku zbog nevažećeg kontrolnog broja",
    "%s password reset" : "%s lozinka ponovo postavljena",
    "Couldn't send reset email. Please contact your administrator." : "Nemoguće slanje e-mail-a za ponovno postavljanje lozinke. Molimo Vas kontaktirajte Vašeg administratora",
    "Couldn't send mail to following users: %s " : "Nije bilo moguće poslati e-mail sledećim korisnicima: %s",
    "Turned on maintenance mode" : "Uključen je režim za održavanje",
    "Turned off maintenance mode" : "Isključen je režim za održavanje",
    "Updated database" : "Osvežena je baza podataka",
    "Checked database schema update" : "Provereno je osvežavanje šema baze podataka",
    "Checked database schema update for apps" : "Provereno je osvežavanje šema baze podataka za aplikacije",
    "Updated \"%s\" to %s" : "Osveženo je \"%s\" na \"%s\"",
    "Sunday" : "Nedelja",
    "Monday" : "Ponedeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Sreda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "ned",
    "Mon." : "pon",
    "Tue." : "uto",
    "Wed." : "sre",
    "Thu." : "čet",
    "Fri." : "pet",
    "Sat." : "sub",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mart",
    "April" : "April",
    "May" : "Maj",
    "June" : "Jun",
    "July" : "Jul",
    "August" : "Avgust",
    "September" : "Septembar",
    "October" : "Oktobar",
    "November" : "Novembar",
    "December" : "Decembar",
    "Jan." : "jan",
    "Feb." : "feb",
    "Mar." : "mar",
    "Apr." : "apr",
    "May." : "maj",
    "Jun." : "jun",
    "Jul." : "jul",
    "Aug." : "avg",
    "Sep." : "sep",
    "Oct." : "okt",
    "Nov." : "nov",
    "Dec." : "dec",
    "Settings" : "Podešavanja",
    "Saving..." : "Snimam...",
    "seconds ago" : "Pre par sekundi",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link za ponovno postavljanje Vaše lozinke je poslat na Vašu e-mail adresu. Ako ga ne primite u razumnom roku, proverite fascikle za neželjenu poštu.<br>Ako ga nema ni tamo, kontaktirajte Vašeg lokalnog administratora.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaši fajlovi su šifrovani. Ako nista omogućili ključ za povrat fajlova, neće biti načina da dobijete ponovo svoje podatke posle promene lozinke.<br />Ako niste sigurni šta da radite, molimo Vas da kontaktirate Vašeg administratora pre nego što nastavite.<br />Da li zaista želite da nastavite?",
    "I know what I'm doing" : "Znam šta radim",
    "Password can not be changed. Please contact your administrator." : "Nije moguće promeniti lozinku. Molimo Vas, kontaktirajte Vašeg administratora.",
    "No" : "Ne",
    "Yes" : "Da",
    "Choose" : "Izaberi",
    "Error loading file picker template: {error}" : "Greška u učitavanju obrasca za izbor fajla: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Greška u učitavanju obrasca poruke: {error}",
    "read-only" : "samo za čitanje",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt fajlova","{count} konflikata fajlova","{count} konflikata fajlova"],
    "One file conflict" : "Jedan konflikt fajlova",
    "New Files" : "Novi Fajlovi",
    "Already existing files" : "Već postojeći fajlovi",
    "Which files do you want to keep?" : "Koje fajlove želite da zadržite ?",
    "If you select both versions, the copied file will have a number added to its name." : "Ako izaberete obe verzije, kopirani fajl će imati broj dodat njegovom imenu.",
    "Cancel" : "Otkaži",
    "Continue" : "Nastavi",
    "(all selected)" : "(svi izabrani)",
    "({count} selected)" : "(izabrano {count})",
    "Error loading file exists template" : "Greška u učitavanju obrasca za postojeći fajl",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Osrednja lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Error occurred while checking server setup" : "Došlo je do greške prilikom provere startovanja servera",
    "Shared" : "Deljeno",
    "Shared with {recipients}" : "Podeljeno sa {recipients}",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri deljenju",
    "Error while unsharing" : "Greška u uklanjanju deljenja",
    "The public link will expire no later than {days} days after it is created" : "Javna prečica će isteći ne kasnije od {days} dana pošto je kreirana",
    "Set expiration date" : "Datum isteka",
    "Expiration" : "Isticanje",
    "Expiration date" : "Datum isteka",
    "Link" : "Prečica",
    "Edit" : "Uredi",
    "Remove" : "Ukloni",
    "Choose a password for the public link" : "Izaberite lozinku za javnu prečicu",
    "Password" : "Lozinka",
    "Name" : "naziv",
    "Allow editing" : "Dozvoli uređivanje",
    "Save" : "Sačuvaj",
    "Sending ..." : "Slanje...",
    "Email sent" : "Email poslat",
    "Email link to person" : "Pošalji link e-mailom",
    "Shared with you and the group {group} by {owner}" : "{owner} podelio sa Vama i grupom {group} ",
    "Shared with you by {owner}" : "Sa vama podelio {owner}",
    "group" : "grupa",
    "remote" : "udaljeni",
    "notify by email" : "obavesti Email-om",
    "Unshare" : "Ukljoni deljenje",
    "can share" : "dozvoljeno deljenje",
    "can edit" : "dozvoljene izmene",
    "create" : "napravi",
    "change" : "izmeni",
    "delete" : "brisanje",
    "access control" : "kontrola pristupa",
    "Share" : "Podeli",
    "Resharing is not allowed" : "Dalje deljenje nije dozvoljeno",
    "Warning" : "Upozorenje",
    "Delete" : "Obriši",
    "Rename" : "Preimenuj",
    "The object type is not specified." : "Tip objekta nije zadan.",
    "Enter new" : "Unesite novi",
    "Add" : "Dodaj",
    "Edit tags" : "Uredi oznake",
    "Error loading dialog template: {error}" : "Greška pri učitavanju obrasca dijaloga: {error}",
    "No tags selected for deletion." : "Nijedna oznaka nije izabrana za brisanje.",
    "unknown text" : "nepoznati tekst",
    "Hello world!" : "Zdravo Svete!",
    "sunny" : "sunčano",
    "Hello {name}, the weather is {weather}" : "Zdravo {name}, vreme je {weather}",
    "_download %n file_::_download %n files_" : ["Preuzmi %n fajl","Preuzmi %n fajlova","Preuzmi %n fajlova"],
    "Please reload the page." : "Molimo, ponovo učitajte stranu.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Ažuriranje nije uspelo. Molimo obavestite <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud zajednicu</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspelo. Prosleđivanje na ownCloud.",
    "Personal" : "Lično",
    "Users" : "Korisnici",
    "Apps" : "Programi",
    "Admin" : "Adninistracija",
    "Help" : "Pomoć",
    "Access forbidden" : "Pristup zabranjen",
    "File not found" : "Fajl nije nađen",
    "The specified document has not been found on the server." : "Traženi dokument nije nađen na serveru.",
    "You can click here to return to %s." : "Možete ovde kliknuti da biste se vratili na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej,\n\nsamo da ti javimo da je %s delio %s sa tobom.\nPogledaj na: %s\n\n",
    "The share will expire on %s." : "Deljeni sadržaj će isteći: %s",
    "Cheers!" : "U zdravlje!",
    "Internal Server Error" : "Interna Serverska Greška",
    "The server encountered an internal error and was unable to complete your request." : "Server je naišao na internu grešku i nije mogao da završi obradu Vašeg upita.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Molimo Vas da kontaktirate administratora servera ako se ova greška ponavlja, molimo da uključite tehničke podatke dole u Vašem izveštaju.",
    "More details can be found in the server log." : "Više detalja se može naći u serverovom logu - zapisniku.",
    "Technical details" : "Tehnički detalji",
    "Remote Address: %s" : "Udaljena adresa: %s",
    "Request ID: %s" : "ID zahteva: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Poruka: %s",
    "File: %s" : "Fajl: %s",
    "Line: %s" : "Linija: %s",
    "Trace" : "Zapisnik: ",
    "Create an <strong>admin account</strong>" : "Napravi <strong>administrativni nalog</strong>",
    "Username" : "Korisničko ime",
    "Storage & database" : "Skladište i baza podataka",
    "Data folder" : "Fascikla podataka",
    "Configure the database" : "Podešavanje baze",
    "Only %s is available." : "Samo %s je na raspolaganju.",
    "Database user" : "Korisnik baze",
    "Database password" : "Lozinka baze",
    "Database name" : "Ime baze",
    "Database tablespace" : "tablespace baze",
    "Database host" : "Domaćin baze",
    "Finish setup" : "Završi podešavanje",
    "Finishing …" : "Završavam ...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej,<br><br>samo ti javljamo da je %s delio <strong>%s</strong> sa tobom.<br><a href=\"%s\">Pogledaj!</a><br><br>",
    "Log out" : "Odjava",
    "Search" : "Traži",
    "Server side authentication failed!" : "Provera identiteta na stani servera nije uspela!",
    "Please contact your administrator." : "Molimo Vas da kontaktirate Vašeg administratora.",
    "Log in" : "Prijavi se",
    "Alternative Logins" : "Alternativne prijave",
    "Use the following link to reset your password: {link}" : "Koristite sledeći link za reset lozinke: {link}",
    "New password" : "Nova lozinka",
    "New Password" : "Nova lozinka",
    "Reset password" : "Resetuj lozinku",
    "This ownCloud instance is currently in single user mode." : "Ova instanca ownCloud-a je trenutno u režimu rada jednog korisnika.",
    "This means only administrators can use the instance." : "Ovo znači da samo administratori mogu da koriste ovu instancu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktirajte Vašeg sistem administratora ako se ova poruka često ili iznenada pojavljuje.",
    "Thank you for your patience." : "Hvala Vam na strpljenju.",
    "You are accessing the server from an untrusted domain." : "Pristupate serveru sa nepouzdanog domena.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "U zavisnosti od Vaše konfiguracije, kao administrator bi ste mogli da upotrebite dugme ispod da podesite da verujete ovom domenu.",
    "Add \"%s\" as trusted domain" : "Dodaj \"%s\" kao domen od poverenja",
    "The theme %s has been disabled." : "Tema %s će biti onemogućena.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Molimo Vas da proverite da li su baza podataka, fascikla sa podešavanjima i fascikla sa podacima bekapovani pre nego što nastavite.",
    "Start update" : "Započni osvežavanje",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Da bi izbegli preduga čekanja na većim instalacijama, možete pokrenuti sledeću komandu iz instalacionog direktorijuma:",
    "This page will refresh itself when the %s instance is available again." : "Ova stranica će se sama osvežiti kada %s instanca ponovo postane dostupna."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
